summaryrefslogtreecommitdiffstats
path: root/src/partcontroller.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:36:08 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:36:08 -0600
commitc3b301575a98e4c3505ad95534d6192b65539dab (patch)
tree532456654ca955508c4a6e7cd6f04db4ce151c53 /src/partcontroller.cpp
parent1623fe64102c18ab098b79656b80f28cef840756 (diff)
downloadtdevelop-c3b301575a98e4c3505ad95534d6192b65539dab.tar.gz
tdevelop-c3b301575a98e4c3505ad95534d6192b65539dab.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'src/partcontroller.cpp')
-rw-r--r--src/partcontroller.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/partcontroller.cpp b/src/partcontroller.cpp
index 65257b1f..368b4c62 100644
--- a/src/partcontroller.cpp
+++ b/src/partcontroller.cpp
@@ -694,7 +694,7 @@ void PartController::integratePart(KParts::Part *part, const KURL &url,
// Document object and our HTMLDocumentationPart
// connect(part, TQT_SIGNAL(fileNameChanged()), this, TQT_SLOT(slotFileNameChanged()));
// Connect to the document's views newtqStatus() signal in order to keep track of the
// modified-status of the document.
if (isTextEditor)
@@ -718,8 +718,8 @@ void PartController::integratePart(KParts::Part *part, const KURL &url,
connect(designerPart, TQT_SIGNAL(editSource(DesignerType, const TQString& )),
API::getInstance()->languageSupport(),
TQT_SLOT(openSource(DesignerType, const TQString& )));
- connect(designerPart, TQT_SIGNAL(newtqStatus(const TQString &, int)),
- this, TQT_SLOT(slotNewDesignertqStatus(const TQString &, int)));
+ connect(designerPart, TQT_SIGNAL(newStatus(const TQString &, int)),
+ this, TQT_SLOT(slotNewDesignerStatus(const TQString &, int)));
}
}
@@ -787,7 +787,7 @@ void PartController::integrateTextEditorPart(KTextEditor::Document* doc)
TQPtrListIterator<KTextEditor::View> it( list );
while ( it.current() )
{
- connect( it, TQT_SIGNAL( newtqStatus() ), this, TQT_SLOT( slotNewtqStatus() ) );
+ connect( it, TQT_SIGNAL( newStatus() ), this, TQT_SLOT( slotNewStatus() ) );
++it;
}
}
@@ -1511,14 +1511,14 @@ bool PartController::reactToDirty( KURL const & url, unsigned char reason )
return true;
}
-void PartController::slotNewDesignertqStatus(const TQString &formName, int status)
+void PartController::slotNewDesignerStatus(const TQString &formName, int status)
{
kdDebug(9000) << k_funcinfo << endl;
kdDebug(9000) << " formName: " << formName << ", status: " << status << endl;
emit documentChangedState( KURL::fromPathOrURL(formName), DocumentState(status) );
}
-void PartController::slotNewtqStatus( )
+void PartController::slotNewStatus( )
{
kdDebug(9000) << k_funcinfo << endl;
@@ -694,7 +694,7 @@ void PartController::integratePart(KParts::Part *part, const KURL &url,
// Document object and our HTMLDocumentationPart
// connect(part, TQT_SIGNAL(fileNameChanged()), this, TQT_SLOT(slotFileNameChanged()));
- // Connect to the document's views newtqStatus() signal in order to keep track of the
+ // Connect to the document's views newStatus() signal in order to keep track of the
// modified-status of the document.
if (isTextEditor)